@@ -2,6 +2,7 @@
 """Main GUI File"""
 import platform
 import logging
+import sys
 from threading import Thread
 import subprocess
 from kivy.app import App
@@ -15,7 +16,6 @@ from shiny_api.modules import get_ipsws
 from shiny_api.modules import load_config as config
 from shiny_api.modules import update_item_price
 
-
 if platform.node() == "Chris-MBP":
     config.DEBUG_CODE = True
     config.DEBUG_LOGGING = False
@@ -86,7 +86,7 @@ class MainGrid(GridLayout):
     def open_serial_scanner_fn(self, _):
         """Open the serial number scanner"""
         # caller.text += "\nrunning..."
-        subprocess.Popen("python -m shiny_api.serial_camera", shell=True)
+        subprocess.Popen(f"{sys.executable} -m shiny_api.serial_camera", shell=True)
         # scanner = camera.SerialCamera()
         # popup_window = Popup(title="Serial Scanner", content=scanner, size_hint=(None, None), size=(1024, 768))
         # popup_window.open()
